@@ -1,11 +1,17 @@
-from expressmoney.api import *
+__all__ = ('LoanPoint', 'LoanPaginationNonePoint', 'PayPoint',)
 
-__all__ = ('LoanAPI', 'PayAPI')
+from typing import OrderedDict, Union
+
+from expressmoney.api import *
 
 SERVICE_NAME = 'loans'
 
 
-class LoansContract(Contract):
+class LoanCreateContract(Contract):
+    sign = serializers.IntegerField()
+
+
+class LoanReadContract(LoanCreateContract):
     OPEN = "OPEN"
     OVERDUE = "OVERDUE"
     STOP_INTEREST = "STOP_INTEREST"
@@ -31,7 +37,6 @@ class LoansContract(Contract):
     expiry_period = serializers.IntegerField()
 
     interests_charged_date = serializers.DateField(allow_null=True)
-    sign = serializers.IntegerField()
     status = serializers.ChoiceField(choices=STATUS_CHOICES)
 
     body_balance = serializers.DecimalField(max_digits=7, decimal_places=0, allow_null=True)
@@ -44,19 +49,54 @@ class LoansContract(Contract):
     comment = serializers.CharField(max_length=2048, allow_blank=True)
 
 
-class PayContract(Contract):
+class LoanPaginationNoneReadContract(LoanReadContract):
+    pagination = None
+
+
+class PayUpdateContract(Contract):
     bank_card_id = serializers.IntegerField()
 
 
-class LoanAPI(API):
-    _contract = LoansContract
-    _service_name = SERVICE_NAME
-    _app = 'loans'
-    _point = 'loan'
+loans_loans_loan = ID(SERVICE_NAME, 'loans', 'loan')
+loans_loans_loan_pagination_none = ID(SERVICE_NAME, 'loans', 'loan', 'pagination_none')
+loans_loans_pay = ID(SERVICE_NAME, 'loans', 'pay')
 
 
-class PayAPI(API):
-    _contract = PayContract
-    _service_name = 'loans'
-    _app = 'loans'
-    _point = 'pay'
+class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
+    _point_id = loans_loans_loan
+    _read_contract = LoanReadContract
+    _create_contract = LoanCreateContract
+
+    def open_loans(self) -> tuple:
+        return self.filter(status=self._read_contract.OPEN_STATUSES)
+
+    def open_loans_last(self) -> Union[None, OrderedDict]:
+        objects = self.open_loans()
+        return objects[-1] if len(objects) > 0 else None
+
+    def _get_related_points(self) -> list:
+        related_points = super()._get_related_points()
+        related_points.append(LoanPaginationNonePoint(self._user))
+        return related_points
+
+
+class LoanPaginationNonePoint(ListPointMixin, ContractPoint):
+    _point_id = loans_loans_loan_pagination_none
+    _read_contract = LoanPaginationNoneReadContract
+
+
+class PayPoint(UpdatePointMixin, ContractObjectPoint):
+    _point_id = loans_loans_pay
+    _update_contract = PayUpdateContract
+
+
+"""
+from django.contrib.auth import get_user_model
+User = get_user_model()
+user = User.objects.get(id=1)
+
+from loans.models import Loan
+loan = Loan.objects.get(id=47)
+print(loan.body_balance)
+
+"""
