@@ -1,6 +1,7 @@
+__all__ = ('BankCardPoint',)
+
 from expressmoney.api import *
 
-__all__ = ('BankCardAPI',)
 
 SERVICE_NAME = 'payments'
 
@@ -79,8 +80,16 @@ class BankCardContract(Contract):
     gateway = serializers.ChoiceField(choices=GATEWAY_CHOICES)
 
 
-class BankCardAPI(API):
-    _contract = BankCardContract
-    _service_name = SERVICE_NAME
-    _app = 'bank_cards'
-    _point = 'bank-card'
+payments_bank_cards_bank_card = ID(SERVICE_NAME, 'bank_cards', 'bank_card')
+
+
+class BankCardPoint(ListPointMixin, CreatePointMixin, ContractPoint):
+    _point_id = payments_bank_cards_bank_card
+    _read_contract = BankCardContract
+
+
+"""
+from django.contrib.auth import get_user_model
+User = get_user_model()
+user = User.objects.get(id=1)
+"""
\ No newline at end of file
