@@ -1,11 +1,22 @@
+__all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfileObjectPoint')
+
 from expressmoney.api import *
 
-__all__ = ('ProfileAPI',)
 
 SERVICE_NAME = 'profiles'
 
 
-class RussianProfileContract(Contract):
+class UserProfileCreateContract(Contract):
+    user_id = serializers.IntegerField(min_value=1)
+    ip = serializers.IPAddressField(protocol='ipv4')
+    http_referer = serializers.URLField()
+
+
+class UserProfileUpdateContract(Contract):
+    last_password = serializers.CharField(max_length=8, allow_blank=True)
+
+
+class RussianProfileReadContract(Contract):
     NONE = 'NONE'
     PASSPORT = "PP"
     DRIVING_LICENCE = "DL"
@@ -58,9 +69,27 @@ class RussianProfileContract(Contract):
     fias_region = serializers.CharField(max_length=256, allow_blank=True)
 
 
-class ProfileAPI(API):
-    _contract = RussianProfileContract
-    _sort_by = False
-    _service_name = SERVICE_NAME
-    _app = 'profiles'
-    _point = 'russian-profile'
+profiles_profiles_russian_profile = ID(SERVICE_NAME, 'profiles', 'russian_profile')
+profiles_profiles_user_profile = ID(SERVICE_NAME, 'profiles', 'user_profile')
+
+
+class RussianProfileObjectPoint(RetrievePointMixin, ContractObjectPoint):
+    _point_id = profiles_profiles_russian_profile
+    _read_contract = RussianProfileReadContract
+
+
+class UserProfilePoint(CreatePointMixin, ContractPoint):
+    _point_id = profiles_profiles_user_profile
+    _create_contract = UserProfileCreateContract
+
+
+class UserProfileObjectPoint(UpdatePointMixin, ContractObjectPoint):
+    _point_id = profiles_profiles_user_profile
+    _update_contract = UserProfileUpdateContract
+
+
+"""
+from django.contrib.auth import get_user_model
+User = get_user_model()
+user = User.objects.get(id=1)
+"""
\ No newline at end of file
