@@ -1,7 +1,4 @@
-"""
-Statuses for Viewflow framework.
-"""
-
+__all__ = ()
 
 EMPTY = 'EMPTY'
 NEW = 'NEW'
